api.currentuser.v1.test_helpers.authmethods package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.test_helpers.authmethods package

## Submodules

## api.currentuser.v1.test_helpers.authmethods.get_current_user_methods module

`api.currentuser.v1.test_helpers.authmethods.get_current_user_methods.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/authmethods, respond with HTTP 403

`api.currentuser.v1.test_helpers.authmethods.get_current_user_methods.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/authmethods, respond with HTTP 404

`api.currentuser.v1.test_helpers.authmethods.get_current_user_methods.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/authmethods, respond with HTTP 200

`api.currentuser.v1.test_helpers.authmethods.get_current_user_methods.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/authmethods, respond with HTTP 401

## Module contents